secrets

package
v0.10.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 2, 2026 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Scan

func Scan(dir string) (*model.SecretsReport, error)

Scan scans the directory for secrets using gitleaks default rules. It returns a report with the count of findings and a deduplicated list of files containing secrets. Actual secret values are never included.

Types

This section is empty.

Jump to