Documentation
¶
Overview ¶
Package ui provides progress display for repository analysis.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewTUIModel ¶
func NewTUIModel(total int) model
NewTUIModel creates a new bubbletea model for the progress TUI.
func PickProjects ¶ added in v0.2.0
Types ¶
type DoneMsg ¶
type DoneMsg struct{}
DoneMsg is sent to the bubbletea program when all repositories are analyzed.
type PlainProgress ¶
type PlainProgress struct {
// contains filtered or unexported fields
}
PlainProgress prints progress messages to a callback function. Used when stderr is not a TTY (e.g., piped output).
func NewPlainProgress ¶
func NewPlainProgress(print func(string)) *PlainProgress
NewPlainProgress creates a new PlainProgress with the given print callback.
func (*PlainProgress) Done ¶
func (p *PlainProgress) Done(total int)
Done prints a completion message.
func (*PlainProgress) Update ¶
func (p *PlainProgress) Update(completed, total int, repoName string)
Update prints a progress message for a completed repository.
type ProgressMsg ¶
ProgressMsg is sent to the bubbletea program when a repository is analyzed.
Click to show internal directories.
Click to hide internal directories.