Documentation
¶
Overview ¶
internal/worker/pool.go
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ProcessFunc ¶
ProcessFunc processes a single repository and returns its stats.
type ProgressFunc ¶
ProgressFunc is called after each repository is processed.
type Result ¶
Result holds the outcome of processing a single repository.
func RunWithProgress ¶
func RunWithProgress(ctx context.Context, repos []model.Repo, concurrency int, process ProcessFunc, onProgress ProgressFunc) []Result
RunWithProgress processes repos concurrently with an optional progress callback.
Click to show internal directories.
Click to hide internal directories.